#include <libint2.h>

#ifdef __cplusplus
extern "C" {
#endif
void OSVRRP1InBra_aB_s__0__m__1___TwoPRep_s__0__s__1___Ab__up_0(const Libint_t* inteval, LIBINT2_REALTYPE* target, const LIBINT2_REALTYPE* src0, const LIBINT2_REALTYPE* src1, const LIBINT2_REALTYPE* src2, const LIBINT2_REALTYPE* src3) {

LIBINT2_REALTYPE*const  stack = target;
{
const int hsi = 0;
{
const int lsi = 0;
{
const int vi = 0;
LIBINT2_REALTYPE fp201;
fp201 = inteval->roe[vi] * src3[((hsi*36+14)*1+lsi)*1];
LIBINT2_REALTYPE fp200;
fp200 = src2[((hsi*36+14)*1+lsi)*1] - fp201;
LIBINT2_REALTYPE fp202;
fp202 = 5 * inteval->oo2e[vi];
LIBINT2_REALTYPE fp199;
fp199 = fp202 * fp200;
LIBINT2_REALTYPE fp204;
fp204 = inteval->WQ_z[vi] * src1[((hsi*45+20)*1+lsi)*1];
LIBINT2_REALTYPE fp205;
fp205 = inteval->QC_z[vi] * src0[((hsi*45+20)*1+lsi)*1];
LIBINT2_REALTYPE fp203;
fp203 = fp205 + fp204;
LIBINT2_REALTYPE fp198;
fp198 = fp203 + fp199;
target[((hsi*55+27)*1+lsi)*1] = fp198;
LIBINT2_REALTYPE fp209;
fp209 = inteval->roe[vi] * src3[((hsi*36+13)*1+lsi)*1];
LIBINT2_REALTYPE fp208;
fp208 = src2[((hsi*36+13)*1+lsi)*1] - fp209;
LIBINT2_REALTYPE fp210;
fp210 = 4 * inteval->oo2e[vi];
LIBINT2_REALTYPE fp207;
fp207 = fp210 * fp208;
LIBINT2_REALTYPE fp212;
fp212 = inteval->WQ_z[vi] * src1[((hsi*45+19)*1+lsi)*1];
LIBINT2_REALTYPE fp213;
fp213 = inteval->QC_z[vi] * src0[((hsi*45+19)*1+lsi)*1];
LIBINT2_REALTYPE fp211;
fp211 = fp213 + fp212;
LIBINT2_REALTYPE fp206;
fp206 = fp211 + fp207;
target[((hsi*55+26)*1+lsi)*1] = fp206;
LIBINT2_REALTYPE fp217;
fp217 = inteval->roe[vi] * src3[((hsi*36+12)*1+lsi)*1];
LIBINT2_REALTYPE fp216;
fp216 = src2[((hsi*36+12)*1+lsi)*1] - fp217;
LIBINT2_REALTYPE fp218;
fp218 = 3 * inteval->oo2e[vi];
LIBINT2_REALTYPE fp215;
fp215 = fp218 * fp216;
LIBINT2_REALTYPE fp220;
fp220 = inteval->WQ_z[vi] * src1[((hsi*45+18)*1+lsi)*1];
LIBINT2_REALTYPE fp221;
fp221 = inteval->QC_z[vi] * src0[((hsi*45+18)*1+lsi)*1];
LIBINT2_REALTYPE fp219;
fp219 = fp221 + fp220;
LIBINT2_REALTYPE fp214;
fp214 = fp219 + fp215;
target[((hsi*55+25)*1+lsi)*1] = fp214;
LIBINT2_REALTYPE fp225;
fp225 = inteval->roe[vi] * src3[((hsi*36+11)*1+lsi)*1];
LIBINT2_REALTYPE fp224;
fp224 = src2[((hsi*36+11)*1+lsi)*1] - fp225;
LIBINT2_REALTYPE fp226;
fp226 = 2 * inteval->oo2e[vi];
LIBINT2_REALTYPE fp223;
fp223 = fp226 * fp224;
LIBINT2_REALTYPE fp228;
fp228 = inteval->WQ_z[vi] * src1[((hsi*45+17)*1+lsi)*1];
LIBINT2_REALTYPE fp229;
fp229 = inteval->QC_z[vi] * src0[((hsi*45+17)*1+lsi)*1];
LIBINT2_REALTYPE fp227;
fp227 = fp229 + fp228;
LIBINT2_REALTYPE fp222;
fp222 = fp227 + fp223;
target[((hsi*55+24)*1+lsi)*1] = fp222;
LIBINT2_REALTYPE fp233;
fp233 = inteval->roe[vi] * src3[((hsi*36+10)*1+lsi)*1];
LIBINT2_REALTYPE fp232;
fp232 = src2[((hsi*36+10)*1+lsi)*1] - fp233;
LIBINT2_REALTYPE fp231;
fp231 = inteval->oo2e[vi] * fp232;
LIBINT2_REALTYPE fp235;
fp235 = inteval->WQ_z[vi] * src1[((hsi*45+16)*1+lsi)*1];
LIBINT2_REALTYPE fp236;
fp236 = inteval->QC_z[vi] * src0[((hsi*45+16)*1+lsi)*1];
LIBINT2_REALTYPE fp234;
fp234 = fp236 + fp235;
LIBINT2_REALTYPE fp230;
fp230 = fp234 + fp231;
target[((hsi*55+23)*1+lsi)*1] = fp230;
LIBINT2_REALTYPE fp238;
fp238 = inteval->WQ_z[vi] * src1[((hsi*45+15)*1+lsi)*1];
LIBINT2_REALTYPE fp239;
fp239 = inteval->QC_z[vi] * src0[((hsi*45+15)*1+lsi)*1];
LIBINT2_REALTYPE fp237;
fp237 = fp239 + fp238;
target[((hsi*55+22)*1+lsi)*1] = fp237;
LIBINT2_REALTYPE fp243;
fp243 = inteval->roe[vi] * src3[((hsi*36+10)*1+lsi)*1];
LIBINT2_REALTYPE fp242;
fp242 = src2[((hsi*36+10)*1+lsi)*1] - fp243;
LIBINT2_REALTYPE fp244;
fp244 = 5 * inteval->oo2e[vi];
LIBINT2_REALTYPE fp241;
fp241 = fp244 * fp242;
LIBINT2_REALTYPE fp246;
fp246 = inteval->WQ_y[vi] * src1[((hsi*45+15)*1+lsi)*1];
LIBINT2_REALTYPE fp247;
fp247 = inteval->QC_y[vi] * src0[((hsi*45+15)*1+lsi)*1];
LIBINT2_REALTYPE fp245;
fp245 = fp247 + fp246;
LIBINT2_REALTYPE fp240;
fp240 = fp245 + fp241;
target[((hsi*55+21)*1+lsi)*1] = fp240;
LIBINT2_REALTYPE fp251;
fp251 = inteval->roe[vi] * src3[((hsi*36+9)*1+lsi)*1];
LIBINT2_REALTYPE fp250;
fp250 = src2[((hsi*36+9)*1+lsi)*1] - fp251;
LIBINT2_REALTYPE fp252;
fp252 = 4 * inteval->oo2e[vi];
LIBINT2_REALTYPE fp249;
fp249 = fp252 * fp250;
LIBINT2_REALTYPE fp254;
fp254 = inteval->WQ_z[vi] * src1[((hsi*45+14)*1+lsi)*1];
LIBINT2_REALTYPE fp255;
fp255 = inteval->QC_z[vi] * src0[((hsi*45+14)*1+lsi)*1];
LIBINT2_REALTYPE fp253;
fp253 = fp255 + fp254;
LIBINT2_REALTYPE fp248;
fp248 = fp253 + fp249;
target[((hsi*55+20)*1+lsi)*1] = fp248;
LIBINT2_REALTYPE fp259;
fp259 = inteval->roe[vi] * src3[((hsi*36+8)*1+lsi)*1];
LIBINT2_REALTYPE fp258;
fp258 = src2[((hsi*36+8)*1+lsi)*1] - fp259;
LIBINT2_REALTYPE fp260;
fp260 = 3 * inteval->oo2e[vi];
LIBINT2_REALTYPE fp257;
fp257 = fp260 * fp258;
LIBINT2_REALTYPE fp262;
fp262 = inteval->WQ_z[vi] * src1[((hsi*45+13)*1+lsi)*1];
LIBINT2_REALTYPE fp263;
fp263 = inteval->QC_z[vi] * src0[((hsi*45+13)*1+lsi)*1];
LIBINT2_REALTYPE fp261;
fp261 = fp263 + fp262;
LIBINT2_REALTYPE fp256;
fp256 = fp261 + fp257;
target[((hsi*55+19)*1+lsi)*1] = fp256;
LIBINT2_REALTYPE fp267;
fp267 = inteval->roe[vi] * src3[((hsi*36+7)*1+lsi)*1];
LIBINT2_REALTYPE fp266;
fp266 = src2[((hsi*36+7)*1+lsi)*1] - fp267;
LIBINT2_REALTYPE fp268;
fp268 = 2 * inteval->oo2e[vi];
LIBINT2_REALTYPE fp265;
fp265 = fp268 * fp266;
LIBINT2_REALTYPE fp270;
fp270 = inteval->WQ_z[vi] * src1[((hsi*45+12)*1+lsi)*1];
LIBINT2_REALTYPE fp271;
fp271 = inteval->QC_z[vi] * src0[((hsi*45+12)*1+lsi)*1];
LIBINT2_REALTYPE fp269;
fp269 = fp271 + fp270;
LIBINT2_REALTYPE fp264;
fp264 = fp269 + fp265;
target[((hsi*55+18)*1+lsi)*1] = fp264;
LIBINT2_REALTYPE fp275;
fp275 = inteval->roe[vi] * src3[((hsi*36+6)*1+lsi)*1];
LIBINT2_REALTYPE fp274;
fp274 = src2[((hsi*36+6)*1+lsi)*1] - fp275;
LIBINT2_REALTYPE fp273;
fp273 = inteval->oo2e[vi] * fp274;
LIBINT2_REALTYPE fp277;
fp277 = inteval->WQ_z[vi] * src1[((hsi*45+11)*1+lsi)*1];
LIBINT2_REALTYPE fp278;
fp278 = inteval->QC_z[vi] * src0[((hsi*45+11)*1+lsi)*1];
LIBINT2_REALTYPE fp276;
fp276 = fp278 + fp277;
LIBINT2_REALTYPE fp272;
fp272 = fp276 + fp273;
target[((hsi*55+17)*1+lsi)*1] = fp272;
LIBINT2_REALTYPE fp280;
fp280 = inteval->WQ_z[vi] * src1[((hsi*45+10)*1+lsi)*1];
LIBINT2_REALTYPE fp281;
fp281 = inteval->QC_z[vi] * src0[((hsi*45+10)*1+lsi)*1];
LIBINT2_REALTYPE fp279;
fp279 = fp281 + fp280;
target[((hsi*55+16)*1+lsi)*1] = fp279;
LIBINT2_REALTYPE fp285;
fp285 = inteval->roe[vi] * src3[((hsi*36+6)*1+lsi)*1];
LIBINT2_REALTYPE fp284;
fp284 = src2[((hsi*36+6)*1+lsi)*1] - fp285;
LIBINT2_REALTYPE fp286;
fp286 = 4 * inteval->oo2e[vi];
LIBINT2_REALTYPE fp283;
fp283 = fp286 * fp284;
LIBINT2_REALTYPE fp288;
fp288 = inteval->WQ_y[vi] * src1[((hsi*45+10)*1+lsi)*1];
LIBINT2_REALTYPE fp289;
fp289 = inteval->QC_y[vi] * src0[((hsi*45+10)*1+lsi)*1];
LIBINT2_REALTYPE fp287;
fp287 = fp289 + fp288;
LIBINT2_REALTYPE fp282;
fp282 = fp287 + fp283;
target[((hsi*55+15)*1+lsi)*1] = fp282;
LIBINT2_REALTYPE fp293;
fp293 = inteval->roe[vi] * src3[((hsi*36+5)*1+lsi)*1];
LIBINT2_REALTYPE fp292;
fp292 = src2[((hsi*36+5)*1+lsi)*1] - fp293;
LIBINT2_REALTYPE fp294;
fp294 = 3 * inteval->oo2e[vi];
LIBINT2_REALTYPE fp291;
fp291 = fp294 * fp292;
LIBINT2_REALTYPE fp296;
fp296 = inteval->WQ_z[vi] * src1[((hsi*45+9)*1+lsi)*1];
LIBINT2_REALTYPE fp297;
fp297 = inteval->QC_z[vi] * src0[((hsi*45+9)*1+lsi)*1];
LIBINT2_REALTYPE fp295;
fp295 = fp297 + fp296;
LIBINT2_REALTYPE fp290;
fp290 = fp295 + fp291;
target[((hsi*55+14)*1+lsi)*1] = fp290;
LIBINT2_REALTYPE fp301;
fp301 = inteval->roe[vi] * src3[((hsi*36+4)*1+lsi)*1];
LIBINT2_REALTYPE fp300;
fp300 = src2[((hsi*36+4)*1+lsi)*1] - fp301;
LIBINT2_REALTYPE fp302;
fp302 = 2 * inteval->oo2e[vi];
LIBINT2_REALTYPE fp299;
fp299 = fp302 * fp300;
LIBINT2_REALTYPE fp304;
fp304 = inteval->WQ_z[vi] * src1[((hsi*45+8)*1+lsi)*1];
LIBINT2_REALTYPE fp305;
fp305 = inteval->QC_z[vi] * src0[((hsi*45+8)*1+lsi)*1];
LIBINT2_REALTYPE fp303;
fp303 = fp305 + fp304;
LIBINT2_REALTYPE fp298;
fp298 = fp303 + fp299;
target[((hsi*55+13)*1+lsi)*1] = fp298;
LIBINT2_REALTYPE fp309;
fp309 = inteval->roe[vi] * src3[((hsi*36+3)*1+lsi)*1];
LIBINT2_REALTYPE fp308;
fp308 = src2[((hsi*36+3)*1+lsi)*1] - fp309;
LIBINT2_REALTYPE fp307;
fp307 = inteval->oo2e[vi] * fp308;
LIBINT2_REALTYPE fp311;
fp311 = inteval->WQ_z[vi] * src1[((hsi*45+7)*1+lsi)*1];
LIBINT2_REALTYPE fp312;
fp312 = inteval->QC_z[vi] * src0[((hsi*45+7)*1+lsi)*1];
LIBINT2_REALTYPE fp310;
fp310 = fp312 + fp311;
LIBINT2_REALTYPE fp306;
fp306 = fp310 + fp307;
target[((hsi*55+12)*1+lsi)*1] = fp306;
LIBINT2_REALTYPE fp314;
fp314 = inteval->WQ_z[vi] * src1[((hsi*45+6)*1+lsi)*1];
LIBINT2_REALTYPE fp315;
fp315 = inteval->QC_z[vi] * src0[((hsi*45+6)*1+lsi)*1];
LIBINT2_REALTYPE fp313;
fp313 = fp315 + fp314;
target[((hsi*55+11)*1+lsi)*1] = fp313;
LIBINT2_REALTYPE fp319;
fp319 = inteval->roe[vi] * src3[((hsi*36+3)*1+lsi)*1];
LIBINT2_REALTYPE fp318;
fp318 = src2[((hsi*36+3)*1+lsi)*1] - fp319;
LIBINT2_REALTYPE fp320;
fp320 = 3 * inteval->oo2e[vi];
LIBINT2_REALTYPE fp317;
fp317 = fp320 * fp318;
LIBINT2_REALTYPE fp322;
fp322 = inteval->WQ_y[vi] * src1[((hsi*45+6)*1+lsi)*1];
LIBINT2_REALTYPE fp323;
fp323 = inteval->QC_y[vi] * src0[((hsi*45+6)*1+lsi)*1];
LIBINT2_REALTYPE fp321;
fp321 = fp323 + fp322;
LIBINT2_REALTYPE fp316;
fp316 = fp321 + fp317;
target[((hsi*55+10)*1+lsi)*1] = fp316;
LIBINT2_REALTYPE fp327;
fp327 = inteval->roe[vi] * src3[((hsi*36+2)*1+lsi)*1];
LIBINT2_REALTYPE fp326;
fp326 = src2[((hsi*36+2)*1+lsi)*1] - fp327;
LIBINT2_REALTYPE fp328;
fp328 = 2 * inteval->oo2e[vi];
LIBINT2_REALTYPE fp325;
fp325 = fp328 * fp326;
LIBINT2_REALTYPE fp330;
fp330 = inteval->WQ_z[vi] * src1[((hsi*45+5)*1+lsi)*1];
LIBINT2_REALTYPE fp331;
fp331 = inteval->QC_z[vi] * src0[((hsi*45+5)*1+lsi)*1];
LIBINT2_REALTYPE fp329;
fp329 = fp331 + fp330;
LIBINT2_REALTYPE fp324;
fp324 = fp329 + fp325;
target[((hsi*55+9)*1+lsi)*1] = fp324;
LIBINT2_REALTYPE fp335;
fp335 = inteval->roe[vi] * src3[((hsi*36+1)*1+lsi)*1];
LIBINT2_REALTYPE fp334;
fp334 = src2[((hsi*36+1)*1+lsi)*1] - fp335;
LIBINT2_REALTYPE fp333;
fp333 = inteval->oo2e[vi] * fp334;
LIBINT2_REALTYPE fp337;
fp337 = inteval->WQ_z[vi] * src1[((hsi*45+4)*1+lsi)*1];
LIBINT2_REALTYPE fp338;
fp338 = inteval->QC_z[vi] * src0[((hsi*45+4)*1+lsi)*1];
LIBINT2_REALTYPE fp336;
fp336 = fp338 + fp337;
LIBINT2_REALTYPE fp332;
fp332 = fp336 + fp333;
target[((hsi*55+8)*1+lsi)*1] = fp332;
LIBINT2_REALTYPE fp340;
fp340 = inteval->WQ_z[vi] * src1[((hsi*45+3)*1+lsi)*1];
LIBINT2_REALTYPE fp341;
fp341 = inteval->QC_z[vi] * src0[((hsi*45+3)*1+lsi)*1];
LIBINT2_REALTYPE fp339;
fp339 = fp341 + fp340;
target[((hsi*55+7)*1+lsi)*1] = fp339;
LIBINT2_REALTYPE fp345;
fp345 = inteval->roe[vi] * src3[((hsi*36+1)*1+lsi)*1];
LIBINT2_REALTYPE fp344;
fp344 = src2[((hsi*36+1)*1+lsi)*1] - fp345;
LIBINT2_REALTYPE fp346;
fp346 = 2 * inteval->oo2e[vi];
LIBINT2_REALTYPE fp343;
fp343 = fp346 * fp344;
LIBINT2_REALTYPE fp348;
fp348 = inteval->WQ_y[vi] * src1[((hsi*45+3)*1+lsi)*1];
LIBINT2_REALTYPE fp349;
fp349 = inteval->QC_y[vi] * src0[((hsi*45+3)*1+lsi)*1];
LIBINT2_REALTYPE fp347;
fp347 = fp349 + fp348;
LIBINT2_REALTYPE fp342;
fp342 = fp347 + fp343;
target[((hsi*55+6)*1+lsi)*1] = fp342;
LIBINT2_REALTYPE fp353;
fp353 = inteval->roe[vi] * src3[((hsi*36+0)*1+lsi)*1];
LIBINT2_REALTYPE fp352;
fp352 = src2[((hsi*36+0)*1+lsi)*1] - fp353;
LIBINT2_REALTYPE fp351;
fp351 = inteval->oo2e[vi] * fp352;
LIBINT2_REALTYPE fp355;
fp355 = inteval->WQ_z[vi] * src1[((hsi*45+2)*1+lsi)*1];
LIBINT2_REALTYPE fp356;
fp356 = inteval->QC_z[vi] * src0[((hsi*45+2)*1+lsi)*1];
LIBINT2_REALTYPE fp354;
fp354 = fp356 + fp355;
LIBINT2_REALTYPE fp350;
fp350 = fp354 + fp351;
target[((hsi*55+5)*1+lsi)*1] = fp350;
LIBINT2_REALTYPE fp358;
fp358 = inteval->WQ_z[vi] * src1[((hsi*45+1)*1+lsi)*1];
LIBINT2_REALTYPE fp359;
fp359 = inteval->QC_z[vi] * src0[((hsi*45+1)*1+lsi)*1];
LIBINT2_REALTYPE fp357;
fp357 = fp359 + fp358;
target[((hsi*55+4)*1+lsi)*1] = fp357;
LIBINT2_REALTYPE fp363;
fp363 = inteval->roe[vi] * src3[((hsi*36+0)*1+lsi)*1];
LIBINT2_REALTYPE fp362;
fp362 = src2[((hsi*36+0)*1+lsi)*1] - fp363;
LIBINT2_REALTYPE fp361;
fp361 = inteval->oo2e[vi] * fp362;
LIBINT2_REALTYPE fp365;
fp365 = inteval->WQ_y[vi] * src1[((hsi*45+1)*1+lsi)*1];
LIBINT2_REALTYPE fp366;
fp366 = inteval->QC_y[vi] * src0[((hsi*45+1)*1+lsi)*1];
LIBINT2_REALTYPE fp364;
fp364 = fp366 + fp365;
LIBINT2_REALTYPE fp360;
fp360 = fp364 + fp361;
target[((hsi*55+3)*1+lsi)*1] = fp360;
LIBINT2_REALTYPE fp368;
fp368 = inteval->WQ_z[vi] * src1[((hsi*45+0)*1+lsi)*1];
LIBINT2_REALTYPE fp369;
fp369 = inteval->QC_z[vi] * src0[((hsi*45+0)*1+lsi)*1];
LIBINT2_REALTYPE fp367;
fp367 = fp369 + fp368;
target[((hsi*55+2)*1+lsi)*1] = fp367;
LIBINT2_REALTYPE fp371;
fp371 = inteval->WQ_y[vi] * src1[((hsi*45+0)*1+lsi)*1];
LIBINT2_REALTYPE fp372;
fp372 = inteval->QC_y[vi] * src0[((hsi*45+0)*1+lsi)*1];
LIBINT2_REALTYPE fp370;
fp370 = fp372 + fp371;
target[((hsi*55+1)*1+lsi)*1] = fp370;
LIBINT2_REALTYPE fp376;
fp376 = inteval->roe[vi] * src3[((hsi*36+0)*1+lsi)*1];
LIBINT2_REALTYPE fp375;
fp375 = src2[((hsi*36+0)*1+lsi)*1] - fp376;
LIBINT2_REALTYPE fp377;
fp377 = 8 * inteval->oo2e[vi];
LIBINT2_REALTYPE fp374;
fp374 = fp377 * fp375;
LIBINT2_REALTYPE fp379;
fp379 = inteval->WQ_x[vi] * src1[((hsi*45+0)*1+lsi)*1];
LIBINT2_REALTYPE fp380;
fp380 = inteval->QC_x[vi] * src0[((hsi*45+0)*1+lsi)*1];
LIBINT2_REALTYPE fp378;
fp378 = fp380 + fp379;
LIBINT2_REALTYPE fp373;
fp373 = fp378 + fp374;
target[((hsi*55+0)*1+lsi)*1] = fp373;
LIBINT2_REALTYPE fp3;
fp3 = inteval->roe[vi] * src3[((hsi*36+35)*1+lsi)*1];
LIBINT2_REALTYPE fp2;
fp2 = src2[((hsi*36+35)*1+lsi)*1] - fp3;
LIBINT2_REALTYPE fp4;
fp4 = 8 * inteval->oo2e[vi];
LIBINT2_REALTYPE fp1;
fp1 = fp4 * fp2;
LIBINT2_REALTYPE fp6;
fp6 = inteval->WQ_z[vi] * src1[((hsi*45+44)*1+lsi)*1];
LIBINT2_REALTYPE fp7;
fp7 = inteval->QC_z[vi] * src0[((hsi*45+44)*1+lsi)*1];
LIBINT2_REALTYPE fp5;
fp5 = fp7 + fp6;
LIBINT2_REALTYPE fp0;
fp0 = fp5 + fp1;
target[((hsi*55+54)*1+lsi)*1] = fp0;
LIBINT2_REALTYPE fp11;
fp11 = inteval->roe[vi] * src3[((hsi*36+34)*1+lsi)*1];
LIBINT2_REALTYPE fp10;
fp10 = src2[((hsi*36+34)*1+lsi)*1] - fp11;
LIBINT2_REALTYPE fp12;
fp12 = 7 * inteval->oo2e[vi];
LIBINT2_REALTYPE fp9;
fp9 = fp12 * fp10;
LIBINT2_REALTYPE fp14;
fp14 = inteval->WQ_z[vi] * src1[((hsi*45+43)*1+lsi)*1];
LIBINT2_REALTYPE fp15;
fp15 = inteval->QC_z[vi] * src0[((hsi*45+43)*1+lsi)*1];
LIBINT2_REALTYPE fp13;
fp13 = fp15 + fp14;
LIBINT2_REALTYPE fp8;
fp8 = fp13 + fp9;
target[((hsi*55+53)*1+lsi)*1] = fp8;
LIBINT2_REALTYPE fp19;
fp19 = inteval->roe[vi] * src3[((hsi*36+33)*1+lsi)*1];
LIBINT2_REALTYPE fp18;
fp18 = src2[((hsi*36+33)*1+lsi)*1] - fp19;
LIBINT2_REALTYPE fp20;
fp20 = 6 * inteval->oo2e[vi];
LIBINT2_REALTYPE fp17;
fp17 = fp20 * fp18;
LIBINT2_REALTYPE fp22;
fp22 = inteval->WQ_z[vi] * src1[((hsi*45+42)*1+lsi)*1];
LIBINT2_REALTYPE fp23;
fp23 = inteval->QC_z[vi] * src0[((hsi*45+42)*1+lsi)*1];
LIBINT2_REALTYPE fp21;
fp21 = fp23 + fp22;
LIBINT2_REALTYPE fp16;
fp16 = fp21 + fp17;
target[((hsi*55+52)*1+lsi)*1] = fp16;
LIBINT2_REALTYPE fp27;
fp27 = inteval->roe[vi] * src3[((hsi*36+32)*1+lsi)*1];
LIBINT2_REALTYPE fp26;
fp26 = src2[((hsi*36+32)*1+lsi)*1] - fp27;
LIBINT2_REALTYPE fp28;
fp28 = 5 * inteval->oo2e[vi];
LIBINT2_REALTYPE fp25;
fp25 = fp28 * fp26;
LIBINT2_REALTYPE fp30;
fp30 = inteval->WQ_z[vi] * src1[((hsi*45+41)*1+lsi)*1];
LIBINT2_REALTYPE fp31;
fp31 = inteval->QC_z[vi] * src0[((hsi*45+41)*1+lsi)*1];
LIBINT2_REALTYPE fp29;
fp29 = fp31 + fp30;
LIBINT2_REALTYPE fp24;
fp24 = fp29 + fp25;
target[((hsi*55+51)*1+lsi)*1] = fp24;
LIBINT2_REALTYPE fp35;
fp35 = inteval->roe[vi] * src3[((hsi*36+31)*1+lsi)*1];
LIBINT2_REALTYPE fp34;
fp34 = src2[((hsi*36+31)*1+lsi)*1] - fp35;
LIBINT2_REALTYPE fp36;
fp36 = 4 * inteval->oo2e[vi];
LIBINT2_REALTYPE fp33;
fp33 = fp36 * fp34;
LIBINT2_REALTYPE fp38;
fp38 = inteval->WQ_z[vi] * src1[((hsi*45+40)*1+lsi)*1];
LIBINT2_REALTYPE fp39;
fp39 = inteval->QC_z[vi] * src0[((hsi*45+40)*1+lsi)*1];
LIBINT2_REALTYPE fp37;
fp37 = fp39 + fp38;
LIBINT2_REALTYPE fp32;
fp32 = fp37 + fp33;
target[((hsi*55+50)*1+lsi)*1] = fp32;
LIBINT2_REALTYPE fp43;
fp43 = inteval->roe[vi] * src3[((hsi*36+30)*1+lsi)*1];
LIBINT2_REALTYPE fp42;
fp42 = src2[((hsi*36+30)*1+lsi)*1] - fp43;
LIBINT2_REALTYPE fp44;
fp44 = 3 * inteval->oo2e[vi];
LIBINT2_REALTYPE fp41;
fp41 = fp44 * fp42;
LIBINT2_REALTYPE fp46;
fp46 = inteval->WQ_z[vi] * src1[((hsi*45+39)*1+lsi)*1];
LIBINT2_REALTYPE fp47;
fp47 = inteval->QC_z[vi] * src0[((hsi*45+39)*1+lsi)*1];
LIBINT2_REALTYPE fp45;
fp45 = fp47 + fp46;
LIBINT2_REALTYPE fp40;
fp40 = fp45 + fp41;
target[((hsi*55+49)*1+lsi)*1] = fp40;
LIBINT2_REALTYPE fp51;
fp51 = inteval->roe[vi] * src3[((hsi*36+29)*1+lsi)*1];
LIBINT2_REALTYPE fp50;
fp50 = src2[((hsi*36+29)*1+lsi)*1] - fp51;
LIBINT2_REALTYPE fp52;
fp52 = 2 * inteval->oo2e[vi];
LIBINT2_REALTYPE fp49;
fp49 = fp52 * fp50;
LIBINT2_REALTYPE fp54;
fp54 = inteval->WQ_z[vi] * src1[((hsi*45+38)*1+lsi)*1];
LIBINT2_REALTYPE fp55;
fp55 = inteval->QC_z[vi] * src0[((hsi*45+38)*1+lsi)*1];
LIBINT2_REALTYPE fp53;
fp53 = fp55 + fp54;
LIBINT2_REALTYPE fp48;
fp48 = fp53 + fp49;
target[((hsi*55+48)*1+lsi)*1] = fp48;
LIBINT2_REALTYPE fp59;
fp59 = inteval->roe[vi] * src3[((hsi*36+28)*1+lsi)*1];
LIBINT2_REALTYPE fp58;
fp58 = src2[((hsi*36+28)*1+lsi)*1] - fp59;
LIBINT2_REALTYPE fp57;
fp57 = inteval->oo2e[vi] * fp58;
LIBINT2_REALTYPE fp61;
fp61 = inteval->WQ_z[vi] * src1[((hsi*45+37)*1+lsi)*1];
LIBINT2_REALTYPE fp62;
fp62 = inteval->QC_z[vi] * src0[((hsi*45+37)*1+lsi)*1];
LIBINT2_REALTYPE fp60;
fp60 = fp62 + fp61;
LIBINT2_REALTYPE fp56;
fp56 = fp60 + fp57;
target[((hsi*55+47)*1+lsi)*1] = fp56;
LIBINT2_REALTYPE fp64;
fp64 = inteval->WQ_z[vi] * src1[((hsi*45+36)*1+lsi)*1];
LIBINT2_REALTYPE fp65;
fp65 = inteval->QC_z[vi] * src0[((hsi*45+36)*1+lsi)*1];
LIBINT2_REALTYPE fp63;
fp63 = fp65 + fp64;
target[((hsi*55+46)*1+lsi)*1] = fp63;
LIBINT2_REALTYPE fp69;
fp69 = inteval->roe[vi] * src3[((hsi*36+28)*1+lsi)*1];
LIBINT2_REALTYPE fp68;
fp68 = src2[((hsi*36+28)*1+lsi)*1] - fp69;
LIBINT2_REALTYPE fp70;
fp70 = 8 * inteval->oo2e[vi];
LIBINT2_REALTYPE fp67;
fp67 = fp70 * fp68;
LIBINT2_REALTYPE fp72;
fp72 = inteval->WQ_y[vi] * src1[((hsi*45+36)*1+lsi)*1];
LIBINT2_REALTYPE fp73;
fp73 = inteval->QC_y[vi] * src0[((hsi*45+36)*1+lsi)*1];
LIBINT2_REALTYPE fp71;
fp71 = fp73 + fp72;
LIBINT2_REALTYPE fp66;
fp66 = fp71 + fp67;
target[((hsi*55+45)*1+lsi)*1] = fp66;
LIBINT2_REALTYPE fp77;
fp77 = inteval->roe[vi] * src3[((hsi*36+27)*1+lsi)*1];
LIBINT2_REALTYPE fp76;
fp76 = src2[((hsi*36+27)*1+lsi)*1] - fp77;
LIBINT2_REALTYPE fp78;
fp78 = 7 * inteval->oo2e[vi];
LIBINT2_REALTYPE fp75;
fp75 = fp78 * fp76;
LIBINT2_REALTYPE fp80;
fp80 = inteval->WQ_z[vi] * src1[((hsi*45+35)*1+lsi)*1];
LIBINT2_REALTYPE fp81;
fp81 = inteval->QC_z[vi] * src0[((hsi*45+35)*1+lsi)*1];
LIBINT2_REALTYPE fp79;
fp79 = fp81 + fp80;
LIBINT2_REALTYPE fp74;
fp74 = fp79 + fp75;
target[((hsi*55+44)*1+lsi)*1] = fp74;
LIBINT2_REALTYPE fp85;
fp85 = inteval->roe[vi] * src3[((hsi*36+26)*1+lsi)*1];
LIBINT2_REALTYPE fp84;
fp84 = src2[((hsi*36+26)*1+lsi)*1] - fp85;
LIBINT2_REALTYPE fp86;
fp86 = 6 * inteval->oo2e[vi];
LIBINT2_REALTYPE fp83;
fp83 = fp86 * fp84;
LIBINT2_REALTYPE fp88;
fp88 = inteval->WQ_z[vi] * src1[((hsi*45+34)*1+lsi)*1];
LIBINT2_REALTYPE fp89;
fp89 = inteval->QC_z[vi] * src0[((hsi*45+34)*1+lsi)*1];
LIBINT2_REALTYPE fp87;
fp87 = fp89 + fp88;
LIBINT2_REALTYPE fp82;
fp82 = fp87 + fp83;
target[((hsi*55+43)*1+lsi)*1] = fp82;
LIBINT2_REALTYPE fp93;
fp93 = inteval->roe[vi] * src3[((hsi*36+25)*1+lsi)*1];
LIBINT2_REALTYPE fp92;
fp92 = src2[((hsi*36+25)*1+lsi)*1] - fp93;
LIBINT2_REALTYPE fp94;
fp94 = 5 * inteval->oo2e[vi];
LIBINT2_REALTYPE fp91;
fp91 = fp94 * fp92;
LIBINT2_REALTYPE fp96;
fp96 = inteval->WQ_z[vi] * src1[((hsi*45+33)*1+lsi)*1];
LIBINT2_REALTYPE fp97;
fp97 = inteval->QC_z[vi] * src0[((hsi*45+33)*1+lsi)*1];
LIBINT2_REALTYPE fp95;
fp95 = fp97 + fp96;
LIBINT2_REALTYPE fp90;
fp90 = fp95 + fp91;
target[((hsi*55+42)*1+lsi)*1] = fp90;
LIBINT2_REALTYPE fp101;
fp101 = inteval->roe[vi] * src3[((hsi*36+24)*1+lsi)*1];
LIBINT2_REALTYPE fp100;
fp100 = src2[((hsi*36+24)*1+lsi)*1] - fp101;
LIBINT2_REALTYPE fp102;
fp102 = 4 * inteval->oo2e[vi];
LIBINT2_REALTYPE fp99;
fp99 = fp102 * fp100;
LIBINT2_REALTYPE fp104;
fp104 = inteval->WQ_z[vi] * src1[((hsi*45+32)*1+lsi)*1];
LIBINT2_REALTYPE fp105;
fp105 = inteval->QC_z[vi] * src0[((hsi*45+32)*1+lsi)*1];
LIBINT2_REALTYPE fp103;
fp103 = fp105 + fp104;
LIBINT2_REALTYPE fp98;
fp98 = fp103 + fp99;
target[((hsi*55+41)*1+lsi)*1] = fp98;
LIBINT2_REALTYPE fp109;
fp109 = inteval->roe[vi] * src3[((hsi*36+23)*1+lsi)*1];
LIBINT2_REALTYPE fp108;
fp108 = src2[((hsi*36+23)*1+lsi)*1] - fp109;
LIBINT2_REALTYPE fp110;
fp110 = 3 * inteval->oo2e[vi];
LIBINT2_REALTYPE fp107;
fp107 = fp110 * fp108;
LIBINT2_REALTYPE fp112;
fp112 = inteval->WQ_z[vi] * src1[((hsi*45+31)*1+lsi)*1];
LIBINT2_REALTYPE fp113;
fp113 = inteval->QC_z[vi] * src0[((hsi*45+31)*1+lsi)*1];
LIBINT2_REALTYPE fp111;
fp111 = fp113 + fp112;
LIBINT2_REALTYPE fp106;
fp106 = fp111 + fp107;
target[((hsi*55+40)*1+lsi)*1] = fp106;
LIBINT2_REALTYPE fp117;
fp117 = inteval->roe[vi] * src3[((hsi*36+22)*1+lsi)*1];
LIBINT2_REALTYPE fp116;
fp116 = src2[((hsi*36+22)*1+lsi)*1] - fp117;
LIBINT2_REALTYPE fp118;
fp118 = 2 * inteval->oo2e[vi];
LIBINT2_REALTYPE fp115;
fp115 = fp118 * fp116;
LIBINT2_REALTYPE fp120;
fp120 = inteval->WQ_z[vi] * src1[((hsi*45+30)*1+lsi)*1];
LIBINT2_REALTYPE fp121;
fp121 = inteval->QC_z[vi] * src0[((hsi*45+30)*1+lsi)*1];
LIBINT2_REALTYPE fp119;
fp119 = fp121 + fp120;
LIBINT2_REALTYPE fp114;
fp114 = fp119 + fp115;
target[((hsi*55+39)*1+lsi)*1] = fp114;
LIBINT2_REALTYPE fp125;
fp125 = inteval->roe[vi] * src3[((hsi*36+21)*1+lsi)*1];
LIBINT2_REALTYPE fp124;
fp124 = src2[((hsi*36+21)*1+lsi)*1] - fp125;
LIBINT2_REALTYPE fp123;
fp123 = inteval->oo2e[vi] * fp124;
LIBINT2_REALTYPE fp127;
fp127 = inteval->WQ_z[vi] * src1[((hsi*45+29)*1+lsi)*1];
LIBINT2_REALTYPE fp128;
fp128 = inteval->QC_z[vi] * src0[((hsi*45+29)*1+lsi)*1];
LIBINT2_REALTYPE fp126;
fp126 = fp128 + fp127;
LIBINT2_REALTYPE fp122;
fp122 = fp126 + fp123;
target[((hsi*55+38)*1+lsi)*1] = fp122;
LIBINT2_REALTYPE fp130;
fp130 = inteval->WQ_z[vi] * src1[((hsi*45+28)*1+lsi)*1];
LIBINT2_REALTYPE fp131;
fp131 = inteval->QC_z[vi] * src0[((hsi*45+28)*1+lsi)*1];
LIBINT2_REALTYPE fp129;
fp129 = fp131 + fp130;
target[((hsi*55+37)*1+lsi)*1] = fp129;
LIBINT2_REALTYPE fp135;
fp135 = inteval->roe[vi] * src3[((hsi*36+21)*1+lsi)*1];
LIBINT2_REALTYPE fp134;
fp134 = src2[((hsi*36+21)*1+lsi)*1] - fp135;
LIBINT2_REALTYPE fp136;
fp136 = 7 * inteval->oo2e[vi];
LIBINT2_REALTYPE fp133;
fp133 = fp136 * fp134;
LIBINT2_REALTYPE fp138;
fp138 = inteval->WQ_y[vi] * src1[((hsi*45+28)*1+lsi)*1];
LIBINT2_REALTYPE fp139;
fp139 = inteval->QC_y[vi] * src0[((hsi*45+28)*1+lsi)*1];
LIBINT2_REALTYPE fp137;
fp137 = fp139 + fp138;
LIBINT2_REALTYPE fp132;
fp132 = fp137 + fp133;
target[((hsi*55+36)*1+lsi)*1] = fp132;
LIBINT2_REALTYPE fp143;
fp143 = inteval->roe[vi] * src3[((hsi*36+20)*1+lsi)*1];
LIBINT2_REALTYPE fp142;
fp142 = src2[((hsi*36+20)*1+lsi)*1] - fp143;
LIBINT2_REALTYPE fp144;
fp144 = 6 * inteval->oo2e[vi];
LIBINT2_REALTYPE fp141;
fp141 = fp144 * fp142;
LIBINT2_REALTYPE fp146;
fp146 = inteval->WQ_z[vi] * src1[((hsi*45+27)*1+lsi)*1];
LIBINT2_REALTYPE fp147;
fp147 = inteval->QC_z[vi] * src0[((hsi*45+27)*1+lsi)*1];
LIBINT2_REALTYPE fp145;
fp145 = fp147 + fp146;
LIBINT2_REALTYPE fp140;
fp140 = fp145 + fp141;
target[((hsi*55+35)*1+lsi)*1] = fp140;
LIBINT2_REALTYPE fp151;
fp151 = inteval->roe[vi] * src3[((hsi*36+19)*1+lsi)*1];
LIBINT2_REALTYPE fp150;
fp150 = src2[((hsi*36+19)*1+lsi)*1] - fp151;
LIBINT2_REALTYPE fp152;
fp152 = 5 * inteval->oo2e[vi];
LIBINT2_REALTYPE fp149;
fp149 = fp152 * fp150;
LIBINT2_REALTYPE fp154;
fp154 = inteval->WQ_z[vi] * src1[((hsi*45+26)*1+lsi)*1];
LIBINT2_REALTYPE fp155;
fp155 = inteval->QC_z[vi] * src0[((hsi*45+26)*1+lsi)*1];
LIBINT2_REALTYPE fp153;
fp153 = fp155 + fp154;
LIBINT2_REALTYPE fp148;
fp148 = fp153 + fp149;
target[((hsi*55+34)*1+lsi)*1] = fp148;
LIBINT2_REALTYPE fp159;
fp159 = inteval->roe[vi] * src3[((hsi*36+18)*1+lsi)*1];
LIBINT2_REALTYPE fp158;
fp158 = src2[((hsi*36+18)*1+lsi)*1] - fp159;
LIBINT2_REALTYPE fp160;
fp160 = 4 * inteval->oo2e[vi];
LIBINT2_REALTYPE fp157;
fp157 = fp160 * fp158;
LIBINT2_REALTYPE fp162;
fp162 = inteval->WQ_z[vi] * src1[((hsi*45+25)*1+lsi)*1];
LIBINT2_REALTYPE fp163;
fp163 = inteval->QC_z[vi] * src0[((hsi*45+25)*1+lsi)*1];
LIBINT2_REALTYPE fp161;
fp161 = fp163 + fp162;
LIBINT2_REALTYPE fp156;
fp156 = fp161 + fp157;
target[((hsi*55+33)*1+lsi)*1] = fp156;
LIBINT2_REALTYPE fp167;
fp167 = inteval->roe[vi] * src3[((hsi*36+17)*1+lsi)*1];
LIBINT2_REALTYPE fp166;
fp166 = src2[((hsi*36+17)*1+lsi)*1] - fp167;
LIBINT2_REALTYPE fp168;
fp168 = 3 * inteval->oo2e[vi];
LIBINT2_REALTYPE fp165;
fp165 = fp168 * fp166;
LIBINT2_REALTYPE fp170;
fp170 = inteval->WQ_z[vi] * src1[((hsi*45+24)*1+lsi)*1];
LIBINT2_REALTYPE fp171;
fp171 = inteval->QC_z[vi] * src0[((hsi*45+24)*1+lsi)*1];
LIBINT2_REALTYPE fp169;
fp169 = fp171 + fp170;
LIBINT2_REALTYPE fp164;
fp164 = fp169 + fp165;
target[((hsi*55+32)*1+lsi)*1] = fp164;
LIBINT2_REALTYPE fp175;
fp175 = inteval->roe[vi] * src3[((hsi*36+16)*1+lsi)*1];
LIBINT2_REALTYPE fp174;
fp174 = src2[((hsi*36+16)*1+lsi)*1] - fp175;
LIBINT2_REALTYPE fp176;
fp176 = 2 * inteval->oo2e[vi];
LIBINT2_REALTYPE fp173;
fp173 = fp176 * fp174;
LIBINT2_REALTYPE fp178;
fp178 = inteval->WQ_z[vi] * src1[((hsi*45+23)*1+lsi)*1];
LIBINT2_REALTYPE fp179;
fp179 = inteval->QC_z[vi] * src0[((hsi*45+23)*1+lsi)*1];
LIBINT2_REALTYPE fp177;
fp177 = fp179 + fp178;
LIBINT2_REALTYPE fp172;
fp172 = fp177 + fp173;
target[((hsi*55+31)*1+lsi)*1] = fp172;
LIBINT2_REALTYPE fp183;
fp183 = inteval->roe[vi] * src3[((hsi*36+15)*1+lsi)*1];
LIBINT2_REALTYPE fp182;
fp182 = src2[((hsi*36+15)*1+lsi)*1] - fp183;
LIBINT2_REALTYPE fp181;
fp181 = inteval->oo2e[vi] * fp182;
LIBINT2_REALTYPE fp185;
fp185 = inteval->WQ_z[vi] * src1[((hsi*45+22)*1+lsi)*1];
LIBINT2_REALTYPE fp186;
fp186 = inteval->QC_z[vi] * src0[((hsi*45+22)*1+lsi)*1];
LIBINT2_REALTYPE fp184;
fp184 = fp186 + fp185;
LIBINT2_REALTYPE fp180;
fp180 = fp184 + fp181;
target[((hsi*55+30)*1+lsi)*1] = fp180;
LIBINT2_REALTYPE fp188;
fp188 = inteval->WQ_z[vi] * src1[((hsi*45+21)*1+lsi)*1];
LIBINT2_REALTYPE fp189;
fp189 = inteval->QC_z[vi] * src0[((hsi*45+21)*1+lsi)*1];
LIBINT2_REALTYPE fp187;
fp187 = fp189 + fp188;
target[((hsi*55+29)*1+lsi)*1] = fp187;
LIBINT2_REALTYPE fp193;
fp193 = inteval->roe[vi] * src3[((hsi*36+15)*1+lsi)*1];
LIBINT2_REALTYPE fp192;
fp192 = src2[((hsi*36+15)*1+lsi)*1] - fp193;
LIBINT2_REALTYPE fp194;
fp194 = 6 * inteval->oo2e[vi];
LIBINT2_REALTYPE fp191;
fp191 = fp194 * fp192;
LIBINT2_REALTYPE fp196;
fp196 = inteval->WQ_y[vi] * src1[((hsi*45+21)*1+lsi)*1];
LIBINT2_REALTYPE fp197;
fp197 = inteval->QC_y[vi] * src0[((hsi*45+21)*1+lsi)*1];
LIBINT2_REALTYPE fp195;
fp195 = fp197 + fp196;
LIBINT2_REALTYPE fp190;
fp190 = fp195 + fp191;
target[((hsi*55+28)*1+lsi)*1] = fp190;
}
}
}
const int hsi = 0;
const int lsi = 0;
const int vi = 0;
/** Number of flops = 381 */
}

#ifdef __cplusplus
};
#endif
